@@ -136,12 +136,11 @@ def _remove_files(file_list):
             raise FileNotFoundError
 
 
-def _generate_azure_filename(file_number):
-    """Generate filename for azure report with uuid and file number suffix."""
-    uuid_part = str(uuid4())
-    suffix = f"{file_number:04d}"
-    output_file_name = f"{uuid_part}_{suffix}.csv"
-    local_path = os.path.join(os.getcwd(), output_file_name)
+def _generate_azure_filename():
+    """Generate filename for azure report."""
+    output_file_name = "{}_{}".format("costreport", uuid4())
+    local_path = f"{os.getcwd()}/{output_file_name}.csv"
+    output_file_name = output_file_name + ".csv"
     return (local_path, output_file_name)
 
 
@@ -732,9 +731,9 @@ def aws_create_report(options):  # noqa: C901
 
 def azure_create_report(options):  # noqa: C901
     """Create a cost usage report file."""
+    data = []
     start_date = options.get("start_date")
     end_date = options.get("end_date")
-    row_limit = options.get("row_limit")
     static_report_data = options.get("static_report_data")
     if static_report_data:
         generators = _get_generators(static_report_data.get("generators"))
@@ -768,7 +767,6 @@ def azure_create_report(options):  # noqa: C901
     write_monthly = options.get("write_monthly", False)
     for month in months:
         data = []
-        file_number = 0
         monthly_files = []
         num_gens = len(generators)
         ten_percent = int(num_gens * 0.1) if num_gens > 50 else 5
@@ -795,40 +793,33 @@ def azure_create_report(options):  # noqa: C901
             attributes["resource_group_export"] = resource_group_export
             gen = generator_cls(gen_start_date, gen_end_date, currency, account_info, attributes)
             azure_columns = gen.azure_columns
-            for hour in gen.generate_data():
-                data.append(hour)
-                if row_limit and len(data) >= row_limit:
-                    file_number += 1
-                    local_path, output_file_name = _generate_azure_filename(file_number)
-                    _write_csv(local_path, data, azure_columns)
-                    monthly_files.append(local_path)
-                    data.clear()
-
+            data += gen.generate_data()
             meter_cache = gen.get_meter_cache()
 
             if count % ten_percent == 0:
                 LOG.info(f"Done with {count} of {num_gens} generators.")
 
-        if data:
-            file_number += 1
-            local_path, output_file_name = _generate_azure_filename(file_number)
-            _write_csv(local_path, data, azure_columns)
-            monthly_files.append(local_path)
-
+        local_path, output_file_name = _generate_azure_filename()
         date_range = _generate_azure_date_range(month)
 
-        for path in monthly_files:
-            output_file_name = os.path.basename(path)
-            file_path = f"{azure_report_name}/{date_range}/{output_file_name}"
+        _write_csv(local_path, data, azure_columns)
+        monthly_files.append(local_path)
+
+        if azure_container_name:
+            file_path = ""
             if azure_prefix_name:
-                file_path = f"{azure_prefix_name}/{file_path}"
-
-            if azure_container_name:
-                if storage_account_name:
-                    azure_route_file(storage_account_name, azure_container_name, path, file_path)
-                else:
-                    azure_route_file(azure_container_name, file_path, path)
+                file_path += azure_prefix_name + "/"
+            file_path += azure_report_name + "/"
+            file_path += date_range + "/"
+            file_path += output_file_name
 
+            # azure blob upload
+            storage_account_name = options.get("azure_account_name", None)
+            if storage_account_name:
+                azure_route_file(storage_account_name, azure_container_name, local_path, file_path)
+            # local dir upload
+            else:
+                azure_route_file(azure_container_name, file_path, local_path)
         if not write_monthly:
             _remove_files(monthly_files)
 
@@ -1029,7 +1020,7 @@ def ocp_create_report(options):  # noqa: C901
             _remove_files(monthly_ros_files)
 
 
-def write_gcp_file(start_date, end_date, data, options, file_number):
+def write_gcp_file(start_date, end_date, data, options):
     """Write GCP data to a file."""
     report_prefix = options.get("gcp_report_prefix")
     etag = options.get("gcp_etag") if options.get("gcp_etag") else str(uuid4())
@@ -1037,13 +1028,10 @@ def write_gcp_file(start_date, end_date, data, options, file_number):
         invoice_month = start_date.strftime("%Y%m")
         scan_start = start_date.date()
         scan_end = end_date.date()
-
-        base_name = f"{invoice_month}_{etag}_{scan_start}:{scan_end}"
-        file_name = f"{base_name}_{file_number:04d}.csv"
+        file_name = f"{invoice_month}_{etag}_{scan_start}:{scan_end}.csv"
     else:
-        file_name = f"{report_prefix}_{file_number:04d}.csv"
-
-    local_file_path = os.path.join(os.getcwd(), file_name)
+        file_name = report_prefix + ".csv"
+    local_file_path = f"{os.getcwd()}/{file_name}"
     output_file_name = f"{etag}/{file_name}"
     columns = GCP_REPORT_COLUMNS
     if options.get("gcp_resource_level", False):
@@ -1177,8 +1165,6 @@ def gcp_create_report(options):  # noqa: C901
         months = _create_month_list(start_date, end_date)
         monthly_files = []
         output_files = []
-        row_limit = options.get("row_limit")
-        file_number = 0
         for month in months:
             data = []
             gen_start_date = month.get("start")
@@ -1204,28 +1190,15 @@ def gcp_create_report(options):  # noqa: C901
                     generator_cls = generator.get("generator")
                     gen = generator_cls(gen_start_date, gen_end_date, currency, project, attributes=attributes)
                     for hour in gen.generate_data():
-                        data.append(hour)
-                        if row_limit and len(data) >= row_limit:
-                            file_number += 1
-                            local_file_path, output_file_name = write_gcp_file(
-                                gen_start_date, gen_end_date, data, options, file_number=file_number
-                            )
-                            output_files.append(output_file_name)
-                            if local_file_path not in monthly_files:
-                                monthly_files.append(local_file_path)
-                            data.clear()
-
+                        data += [hour]
+                    count += 1
                     if count % ten_percent == 0:
                         LOG.info(f"Done with {count} of {num_gens} generators.")
 
-            if data:
-                file_number += 1
-                local_file_path, output_file_name = write_gcp_file(
-                    gen_start_date, gen_end_date, data, options, file_number=file_number
-                )
-                output_files.append(output_file_name)
-                if local_file_path not in monthly_files:
-                    monthly_files.append(local_file_path)
+            local_file_path, output_file_name = write_gcp_file(gen_start_date, gen_end_date, data, options)
+            output_files.append(output_file_name)
+            if local_file_path not in monthly_files:
+                monthly_files.append(local_file_path)
 
         for index, month_file in enumerate(monthly_files):
             if gcp_bucket_name:
